@@ -12,9 +12,9 @@ impl Stopwatch {
         let name = name.into();
         Stopwatch {
             name,
-            start:    time::Instant::now(),
+            start: time::Instant::now(),
             treshold: treshold_ms * 1_000_000,
-            stopped:  false,
+            stopped: false,
         }
     }
     pub fn stop(&mut self) {
@@ -26,7 +26,7 @@ impl Stopwatch {
         if elapsed.as_secs() == 0 && elapsed.subsec_nanos() < (self.treshold as u32) {
             return;
         }
-        debug!("<STOPWATCH> {}: {:?}", self.name, elapsed);
+        debug!("<STOPWATCH> {}: {:?}", self.name, elapsed.as_nanos());
     }
 }
 
